# Generated by Django 4.2.19 on 2025-03-12 16:50
from pathlib import Path

from django.conf import settings
from django.core.files.storage import default_storage
from django.db import migrations

from geotrek.common.utils.file_infos import is_a_non_svg_image


def remove_information_desk_incorrect_photos(apps, schema_editor):
    """
    Remove InformationDesk photos that are not images or SVGs after
    backing them up as attachments
    """
    InformationDesk = apps.get_model("tourism", "InformationDesk")
    Attachment = apps.get_model("common", "Attachment")

    FileType = apps.get_model("common", "FileType")
    file_type = None
    ContentType = apps.get_model("contenttypes", "ContentType")

    User = apps.get_model(settings.AUTH_USER_MODEL)
    creator, created = User.objects.get_or_create(
        username="__internal__", defaults={"is_active": False}
    )

    for info_desk in InformationDesk.objects.all():
        # ImageField does not support svg files
        if (
            info_desk.photo
            and default_storage.exists(info_desk.photo.name)
            and not is_a_non_svg_image(info_desk.photo)
        ):
            if not file_type:
                file_type, created = FileType.objects.get_or_create(
                    type="InformationDesk file backup"
                )
            attachment = Attachment()
            attachment.object_id = info_desk.pk
            attachment.content_type = ContentType.objects.get_for_model(InformationDesk)
            attachment.attachment_file = info_desk.photo
            attachment.filetype = file_type
            attachment.creator = creator
            attachment.title = Path(info_desk.photo.name).name
            attachment.save()

            info_desk.photo = None
            info_desk.save()


class Migration(migrations.Migration):
    dependencies = [
        ("tourism", "0054_alter_touristiccontent_options"),
    ]

    operations = [
        migrations.RunPython(
            remove_information_desk_incorrect_photos, migrations.RunPython.noop
        )
    ]
